@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 # Generic modular configuration file manager.
 #
 # Author: Dave Dittrich <dave.dittrich@gmail.com>
@@ -5,7 +7,8 @@
 
 # Make this module work with "python -m"
 
-from psec.main import *
+import sys
+from psec.main import main
 
 if __name__ == '__main__':
     sys.exit(main(sys.argv[1:]))
